@@ -1,4 +1,4 @@
-"""List virtual server credentials."""
+"""List server credentials."""
 # :license: MIT, see LICENSE for more details.
 
 import click
@@ -7,13 +7,14 @@ import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 from SoftLayer.CLI import helpers
+from SoftLayer import exceptions
 
 
 @click.command()
 @click.argument('identifier')
 @environment.pass_env
 def cli(env, identifier):
-    """List virtual server credentials."""
+    """List server credentials."""
 
     manager = SoftLayer.HardwareManager(env.client)
     hardware_id = helpers.resolve_id(manager.resolve_ids,
@@ -22,6 +23,9 @@ def cli(env, identifier):
     instance = manager.get_hardware(hardware_id)
 
     table = formatting.Table(['username', 'password'])
+    if 'passwords' not in instance['operatingSystem']:
+        raise exceptions.SoftLayerError("No passwords found in operatingSystem")
+
     for item in instance['operatingSystem']['passwords']:
-        table.add_row([item['username'], item['password']])
+        table.add_row([item.get('username', 'None'), item.get('password', 'None')])
     env.fout(table)
