@@ -203,6 +203,14 @@ ALL_ROUTES = [
     ('object-storage:endpoints',
      'SoftLayer.CLI.object_storage.list_endpoints:cli'),
 
+    ('order', 'SoftLayer.CLI.order'),
+    ('order:category-list', 'SoftLayer.CLI.order.category_list:cli'),
+    ('order:item-list', 'SoftLayer.CLI.order.item_list:cli'),
+    ('order:package-list', 'SoftLayer.CLI.order.package_list:cli'),
+    ('order:place', 'SoftLayer.CLI.order.place:cli'),
+    ('order:preset-list', 'SoftLayer.CLI.order.preset_list:cli'),
+    ('order:package-locations', 'SoftLayer.CLI.order.package_locations:cli'),
+
     ('rwhois', 'SoftLayer.CLI.rwhois'),
     ('rwhois:edit', 'SoftLayer.CLI.rwhois.edit:cli'),
     ('rwhois:show', 'SoftLayer.CLI.rwhois.show:cli'),
@@ -223,6 +231,7 @@ ALL_ROUTES = [
     ('hardware:credentials', 'SoftLayer.CLI.hardware.credentials:cli'),
     ('hardware:update-firmware', 'SoftLayer.CLI.hardware.update_firmware:cli'),
     ('hardware:rescue', 'SoftLayer.CLI.hardware.power:rescue'),
+    ('hardware:ready', 'SoftLayer.CLI.hardware.ready:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
@@ -273,6 +282,15 @@ ALL_ROUTES = [
     ('ticket:attach', 'SoftLayer.CLI.ticket.attach:cli'),
     ('ticket:detach', 'SoftLayer.CLI.ticket.detach:cli'),
 
+    ('user', 'SoftLayer.CLI.user'),
+    ('user:list', 'SoftLayer.CLI.user.list:cli'),
+    ('user:detail', 'SoftLayer.CLI.user.detail:cli'),
+    ('user:permissions', 'SoftLayer.CLI.user.permissions:cli'),
+    ('user:edit-permissions', 'SoftLayer.CLI.user.edit_permissions:cli'),
+    ('user:edit-details', 'SoftLayer.CLI.user.edit_details:cli'),
+    ('user:create', 'SoftLayer.CLI.user.create:cli'),
+    ('user:delete', 'SoftLayer.CLI.user.delete:cli'),
+
     ('vlan', 'SoftLayer.CLI.vlan'),
     ('vlan:detail', 'SoftLayer.CLI.vlan.detail:cli'),
     ('vlan:list', 'SoftLayer.CLI.vlan.list:cli'),
